@@ -18,13 +18,13 @@
  */
 package org.pdfsam.test;
 
-import static org.sejda.eventstudio.StaticStudio.eventStudio;
+import static org.pdfsam.eventstudio.StaticStudio.eventStudio;
 
 import java.util.Arrays;
 import java.util.Set;
 
 import org.junit.rules.ExternalResource;
-import org.sejda.common.collection.NullSafeSet;
+import org.sejda.commons.collection.NullSafeSet;
 
 /**
  * Rule that makes sure that event studio listeners are cleared after each test
