@@ -19,15 +19,16 @@
 package org.pdfsam.ui.module;
 
 import static org.apache.commons.lang3.StringUtils.defaultString;
-import static org.sejda.eventstudio.StaticStudio.eventStudio;
+import static org.pdfsam.eventstudio.StaticStudio.eventStudio;
 
 import java.math.BigDecimal;
 
 import org.apache.commons.lang3.StringUtils;
 import org.pdfsam.i18n.DefaultI18nContext;
+import org.pdfsam.module.ModuleOwned;
 import org.pdfsam.module.TaskExecutionRequestEvent;
-import org.sejda.eventstudio.annotation.EventListener;
-import org.sejda.eventstudio.annotation.EventStation;
+import org.pdfsam.eventstudio.annotation.EventListener;
+import org.pdfsam.eventstudio.annotation.EventStation;
 import org.sejda.model.notification.event.PercentageOfWorkDoneChangedEvent;
 import org.sejda.model.notification.event.TaskExecutionCompletedEvent;
 import org.sejda.model.notification.event.TaskExecutionFailedEvent;
@@ -47,7 +48,7 @@ import javafx.scene.layout.VBox;
  * @author Andrea Vacondio
  *
  */
-public class Footer extends HBox {
+public class Footer extends HBox implements ModuleOwned {
 
     private ProgressBar bar = new ProgressBar(0);
     private Label statusLabel = new Label();
@@ -95,6 +96,7 @@ public class Footer extends HBox {
         return runButton;
     }
 
+    @Override
     @EventStation
     public String getOwnerModule() {
         return ownerModule;
