@@ -19,7 +19,7 @@
 package org.pdfsam.ui.io;
 
 import static org.junit.Assert.assertEquals;
-import static org.sejda.eventstudio.StaticStudio.eventStudio;
+import static org.pdfsam.eventstudio.StaticStudio.eventStudio;
 
 import java.io.File;
 import java.io.IOException;
