@@ -18,7 +18,7 @@
  */
 package org.pdfsam.ui.selection;
 
-import static org.mockito.Matchers.any;
+import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.verify;
 import static org.pdfsam.eventstudio.StaticStudio.eventStudio;
