@@ -19,15 +19,15 @@
 package org.pdfsam.premium;
 
 import static java.util.Objects.nonNull;
-import static org.sejda.eventstudio.StaticStudio.eventStudio;
+import static org.pdfsam.eventstudio.StaticStudio.eventStudio;
 
 import java.util.concurrent.CompletableFuture;
 
 import javax.inject.Inject;
 
 import org.pdfsam.i18n.DefaultI18nContext;
-import org.sejda.eventstudio.annotation.EventListener;
-import org.sejda.injector.Auto;
+import org.pdfsam.injector.Auto;
+import org.pdfsam.eventstudio.annotation.EventListener;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
