@@ -18,8 +18,8 @@
  */
 package org.pdfsam.ui;
 
-import org.sejda.injector.Components;
-import org.sejda.injector.Provides;
+import org.pdfsam.injector.Components;
+import org.pdfsam.injector.Provides;
 
 /**
  * @author Andrea Vacondio
